# Generated by Django 3.1.12 on 2021-08-31 07:54

import django.db.models.deletion
import django_cryptography.fields
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="TapConfig",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("publishable_api_key", models.CharField(max_length=400, unique=True)),
                (
                    "secret",
                    django_cryptography.fields.encrypt(
                        models.CharField(max_length=3000)
                    ),
                ),
            ],
            options={"verbose_name": "TAP Config",},
        ),
        migrations.CreateModel(
            name="TapTransaction",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "status",
                    models.CharField(
                        choices=[
                            ("INITIATED", "Initiated"),
                            ("IN_PROGRESS", "In Progress"),
                            ("ABANDONED", "Abandoned"),
                            ("CANCELLED", "Cancelled"),
                            ("FAILED", "Failed"),
                            ("DECLINED", "Declined"),
                            ("RESTRICTED", "Restricted"),
                            ("CAPTURED", "Captured"),
                            ("VOID", "Void"),
                            ("TIMEDOUT", "Timedout"),
                            ("UNKNOWN", "Unknown"),
                        ],
                        max_length=100,
                    ),
                ),
                (
                    "langid",
                    models.CharField(
                        help_text="Capture language for debugging & analytical only purposes (ARA for Arabic & ENG for English)",
                        max_length=10,
                    ),
                ),
                ("amount", models.DecimalField(decimal_places=3, max_digits=20)),
                (
                    "result",
                    models.CharField(
                        help_text="Status response from TAP gateway", max_length=100
                    ),
                ),
                (
                    "payment_url",
                    models.CharField(
                        help_text="Captures generated URL for user payment",
                        max_length=250,
                    ),
                ),
                (
                    "charge_id",
                    models.CharField(
                        db_index=True,
                        help_text="Charge ID returned from TAP",
                        max_length=250,
                        unique=True,
                    ),
                ),
                (
                    "init_response",
                    models.JSONField(
                        blank=True,
                        help_text="Response received when initiating the payment",
                        null=True,
                    ),
                ),
                (
                    "callback_response",
                    models.JSONField(
                        blank=True,
                        help_text="Callback response received after the payment is done",
                        null=True,
                    ),
                ),
                (
                    "encrypt_key",
                    models.BinaryField(blank=True, max_length=200, null=True),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="Datetime when payment was initiated",
                        verbose_name="Created at",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(auto_now=True, verbose_name="Updated at"),
                ),
                (
                    "config",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="transactions",
                        to="payment_tap.tapconfig",
                    ),
                ),
                (
                    "user",
                    models.ForeignKey(
                        help_text="Captured the User ID for both registered users and Guests (Every guest user has a user_id assigned by device_id)",
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={"verbose_name": "TAP Transaction",},
        ),
    ]
